@@ -42,6 +42,8 @@
 //! }
 //!
 //! // This type is laid out as (u32, char, bool)
+//! // In this example, the architecture is assumed to be little-endian
+//! # #[cfg(target_endian = "little")]
 //! unsafe {
 //!     // These are valid bytes for (0, 'x', true)
 //!     Test::check_bytes(
@@ -113,9 +115,17 @@
 //!
 //! - [`uuid`](https://docs.rs/uuid)
 
-#![deny(broken_intra_doc_links)]
-#![deny(missing_docs)]
-#![deny(missing_crate_level_docs)]
+#![deny(
+    broken_intra_doc_links,
+    missing_crate_level_docs,
+    missing_docs,
+    rust_2018_compatibility,
+    rust_2018_idioms,
+    future_incompatible,
+    nonstandard_style,
+    unused,
+    clippy::all
+)]
 #![cfg_attr(not(feature = "std"), no_std)]
 
 #[cfg(not(feature = "std"))]
@@ -131,6 +141,8 @@ extern crate alloc;
 #[cfg(feature = "uuid")]
 pub mod uuid;
 
+#[cfg(not(feature = "simdutf8"))]
+use core::str::{from_utf8, Utf8Error};
 #[cfg(has_atomics)]
 use core::sync::atomic::{
     AtomicBool, AtomicI16, AtomicI32, AtomicI8, AtomicU16, AtomicU32, AtomicU8,
@@ -148,8 +160,6 @@ use core::{
     ops, ptr, slice,
 };
 use ptr_meta::PtrExt;
-#[cfg(not(feature = "simdutf8"))]
-use core::str::{from_utf8, Utf8Error};
 #[cfg(all(feature = "simdutf8", not(feature = "verbose")))]
 use simdutf8::basic::{from_utf8, Utf8Error};
 #[cfg(all(feature = "simdutf8", feature = "verbose"))]
@@ -663,11 +673,9 @@ impl<T: CheckBytes<C>, C: ?Sized> CheckBytes<C> for ops::Range<T> {
                 inner: ErrorBox::new(error),
             }
         })?;
-        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| {
-            StructCheckError {
-                field_name: "end",
-                inner: ErrorBox::new(error),
-            }
+        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| StructCheckError {
+            field_name: "end",
+            inner: ErrorBox::new(error),
         })?;
         Ok(&*value)
     }
@@ -709,11 +717,9 @@ impl<T: CheckBytes<C>, C: ?Sized> CheckBytes<C> for ops::RangeTo<T> {
         value: *const Self,
         context: &mut C,
     ) -> Result<&'a Self, Self::Error> {
-        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| {
-            StructCheckError {
-                field_name: "end",
-                inner: ErrorBox::new(error),
-            }
+        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| StructCheckError {
+            field_name: "end",
+            inner: ErrorBox::new(error),
         })?;
         Ok(&*value)
     }
@@ -727,11 +733,9 @@ impl<T: CheckBytes<C>, C: ?Sized> CheckBytes<C> for ops::RangeToInclusive<T> {
         value: *const Self,
         context: &mut C,
     ) -> Result<&'a Self, Self::Error> {
-        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| {
-            StructCheckError {
-                field_name: "end",
-                inner: ErrorBox::new(error),
-            }
+        T::check_bytes(ptr::addr_of!((*value).end), context).map_err(|error| StructCheckError {
+            field_name: "end",
+            inner: ErrorBox::new(error),
         })?;
         Ok(&*value)
     }
